@@ -82,14 +82,14 @@ dm_wrap_tbl_plan <- function(dm, root) {
     has_terminal_child <- !is.na(child_name)
     if (has_terminal_child) {
       wrap_plan <- add_row(wrap_plan, action = "dm_nest_tbl", table = child_name)
-      graph <- igraph::delete.vertices(graph, child_name)
+      graph <- igraph::delete_vertices(graph, child_name)
       positions <- node_type_from_graph(graph, drop = root_name)
     }
     parent_name <- names(positions)[positions == "terminal parent"][1]
     has_terminal_parent <- !is.na(parent_name)
     if (has_terminal_parent) {
       wrap_plan <- add_row(wrap_plan, action = "dm_pack_tbl", table = parent_name)
-      graph <- igraph::delete.vertices(graph, parent_name)
+      graph <- igraph::delete_vertices(graph, parent_name)
       positions <- node_type_from_graph(graph, drop = root_name)
     }
     if (!has_terminal_child && !has_terminal_parent) break
