@@ -5,12 +5,18 @@ mw_cg_make_dm_set_colors <- function(dm, ..., table_names = NULL, color_name = N
   stopifnot(is.character(table_names))
   stopifnot(table_names %in% names(dm))
 
-  table_color <- set_names(table_names, color_name)
+  if (length(table_names) == 1) {
+    table_sym <- sym(table_names)
+  } else {
+    table_sym <- expr(c(!!!syms(table_names)))
+  }
+
+  table_syms <- exprs(!!sym(color_name) := !!table_sym)
 
   list(
     call = expr(dm_set_colors(
       .,
-      !!!syms(table_color)
+      !!!table_syms
     ))
   )
 }
